.. _Glossary:

Glossary
--------

HDF5 is a general purpose binary container format for large scientific datasets.

h5py is a Python library providing low-level bindings to the libhdf5 C-library and a high-level, numpy-aware API to interact with HDF5 files on disk.

Cooler is a Python package providing an API to create COOL files and to interact with them both as data frames and sparse matrices.

The Cooler Schema is a flexible binary schema for Hi-C data based on a two-table sparse data model.

COOL is also the name of an implementation of the Cooler schema using HDF5 as the container format.

Chrom table

Bin table

Pixel table

Contact list

Contact matrix


Some nomenclature subject to change... :)
